@@ -44,7 +44,7 @@ use constant DEBUG_LEVEL => 1;
 
 # Application name and version
 my $application_name = gettext('Qemu Launcher');
-my $version = '1.7.2';
+my $version = '1.7.3';
 
 # Configuration directory, file, and name for default settings
 my $conf_dir = $ENV{'HOME'}.'/.qemu-launcher';
@@ -1238,8 +1238,16 @@ sub run_vm
 		push @qcmd_parts, '-localtime';
 	}
 
-	if ( $config->{'audio'} and $gladexml->get_widget('audiocheckbutton')->
-		sensitive() )
+	if (
+		$config->{'audio'} and 
+		(
+			( $config->{'systype'} eq 'x86' ) or
+			( $config->{'systype'} eq 'x86_64' ) or
+			( $config->{'systype'} eq 'x86-64' ) or
+			( $config->{'systype'} eq 'ppc' ) or
+			( $config->{'systype'} eq 'ppc64' )
+		)
+	)
 	{
 		push @qcmd_parts, '-soundhw';
 		push @qcmd_parts, $config->{'sndtype'};
@@ -1288,11 +1296,25 @@ sub run_vm
 		push @qcmd_parts, join( ',', ($config->{'logthese'}) );
 	}
 
-	if ( $config->{'acceleration'} eq 'disable' )
+	if (
+		( $config->{'acceleration'} eq 'disable' ) and
+		(
+			( $config->{'systype'} eq 'x86' ) or
+			( $config->{'systype'} eq 'x86-64' ) or
+			( $config->{'systype'} eq 'x86_64' )
+		)
+	)
 	{
 		push @qcmd_parts, '-no-kqemu';
 	}
-	elsif ( $config->{'acceleration'} eq 'full' )
+	elsif (
+		( $config->{'acceleration'} eq 'full' ) and
+		(
+			( $config->{'systype'} eq 'x86' ) or
+			( $config->{'systype'} eq 'x86-64' ) or
+			( $config->{'systype'} eq 'x86_64' )
+		)
+	)
 	{
 		push @qcmd_parts, '-kernel-kqemu';
 	}
@@ -2404,11 +2426,19 @@ $systypecombobox->signal_connect('changed' => sub {
 	{
 		$gladexml->get_widget('gfxvgaradiobutton')->set_sensitive($state1);
 		$gladexml->get_widget('gfxpciradiobutton')->set_sensitive($state1);
+
+		$gladexml->get_widget('acceloffradiobutton')->set_sensitive(1);
+		$gladexml->get_widget('accelonradiobutton')->set_sensitive(1);
+		$gladexml->get_widget('accelfullradiobutton')->set_sensitive(1);
 	}
 	else
 	{
 		$gladexml->get_widget('gfxvgaradiobutton')->set_sensitive(0);
 		$gladexml->get_widget('gfxpciradiobutton')->set_sensitive(0);
+
+		$gladexml->get_widget('acceloffradiobutton')->set_sensitive(0);
+		$gladexml->get_widget('accelonradiobutton')->set_sensitive(0);
+		$gladexml->get_widget('accelfullradiobutton')->set_sensitive(0);
 	}
 });
 
